#define WIN32_LEAN_AND_MEAN

#include <iostream>
#include <stdint.h>
#include <windows.h> // Sleep()


#include "RTC4ethimpl.h"

char cpIp[16]; 		// char pointer for an IP address in decimal dotted notation
char cpNm[16];		// char pointer for a netmask in decimal dotted notation


void handle_network_error(char* cp)
{
	int eth_error = eth_status();
	if (eth_error != 0)
	{
		printf("network error occured while calling %s, error = %d\r\n", cp, eth_error);
	}
}

int main(int argc, char **argv)
{


	uint32_t error;
	uint32_t eth_error;

	uint32_t ip;


	// The RTC4eth has a static IP address programmed or has a DHCP server address reservation
	ip = convert_string_to_ip("172.16.48.15");


	// Try to acquire card
	// More than one try can be reasonable if it can't be ruled out that the RTC4eth is blocked by a previous (lost) connection
	// In this case, add a second try after a delay of 1000 ms.
	// If the card optains its IP address via auto-IP, a higher number of attempts might make sense (~ 15 s delay with IP assignment via DHCP)

	int i = 0;
	int maxTries = 2;
	do
	{
		error = acquire_rtc(ip);
		printf("acquire result = %d\r\n", error);
		Sleep(1000);
	} while ((error != 0) && (++i < maxTries));

	
	error = load_correction_file("cor_1to1.ctb", 1, 1.0, 1.0, 0.0, 0.0, 0.0);
	printf("load_correction_file result = %d\r\n", error);
	if (error == 14)
		handle_network_error("load_correction_file");

	error = load_program_file("RTC4D2.hex");
	printf("load_program_file result = %d\r\n", error);
	if (error == 14)
		handle_network_error("load_program_file");


	set_start_list(1);

	timed_jump_abs(-(1<<15), -(1<<15), 1e6);
	timed_jump_abs((1<<15)-1, (1<<15)-1, 1e6);
	timed_jump_abs(0, 0, 1e6);
	
	set_end_of_list();
	handle_network_error("set_end_of_list");

	execute_list(1);
	
	unsigned short int busy, position;

	do {
		get_status(&busy, &position);
		handle_network_error("get_status");
	} while(busy);


	release_rtc(ip);

	printf("\r\n");
	system("pause");


}